==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/worldfame.lua <==

node_bestSolution("start", 54, "Pavel Danihelka")
node_bestSolution("briefcase", 225, "Pavel Danihelka")
node_bestSolution("cellar", 375, "Pavel Danihelka")
node_bestSolution("library", 111, "Pavel Danihelka")
node_bestSolution("stairs", 163, "Pavel Danihelka")
node_bestSolution("broom", 193, "Ivo Danihelka")
node_bestSolution("reef", 169, "Pavel Danihelka")
node_bestSolution("wc", 100, "Pavel Danihelka")
 
node_bestSolution("submarine", 83, "Pavel Danihelka")
node_bestSolution("party1", 236, "Mark Byers")
node_bestSolution("elk", 257, "Pavel Danihelka")
node_bestSolution("wreck", 91, "Hynek Vychodil")
node_bestSolution("viking1", 119, "Pavel Danihelka")
node_bestSolution("airplane", 235, "Johannes Drescher")
node_bestSolution("bathyscaph", 82, "Pavel Danihelka")
node_bestSolution("tank", 402, "Josef Peterka")
node_bestSolution("viking2", 341, "Uoti Urpala")
node_bestSolution("party2", 283, "Gabor Braun")
node_bestSolution("gods", 537, "Masaaki Irie")
 
node_bestSolution("elevator1", 200, "Pavel Danihelka")
node_bestSolution("city", 481, "Gabor Braun")
node_bestSolution("ufo", 283, "Gabor Braun")
node_bestSolution("columns", 283, "Josef Peterka")
node_bestSolution("pavement", 528, "Gabor Braun")
node_bestSolution("pyramid", 246, "Johan Rönnblom")
node_bestSolution("music", 393, "Josef Peterka")
node_bestSolution("crabshow", 340, "Gabor Braun")
node_bestSolution("elevator2", 455, "Gabor Braun")
node_bestSolution("atlantis", 531, "Uoti Urpala")
 
node_bestSolution("corals", 256, "Josef Peterka")
node_bestSolution("labyrinth", 278, "Mark Byers")
node_bestSolution("imprisoned", 275, "Josef Peterka")
node_bestSolution("society", 110, "Radovan Málek")
node_bestSolution("creatures", 447, "Josef Peterka")
node_bestSolution("cancan", 578, "Mark Byers")
node_bestSolution("pearls", 487, "Gabor Braun")
node_bestSolution("turtle", 688, "Josef Peterka")
 
node_bestSolution("computer", 156, "Josef Peterka")
node_bestSolution("noground", 44, "Heiko Luettges")
node_bestSolution("bathroom", 90, "Josef Peterka")
node_bestSolution("duckie", 98, "Ronny Standtke")
node_bestSolution("puzzle", 144, "Josef Peterka")
node_bestSolution("dump", 426, "Josef Peterka")
node_bestSolution("barrel", 1364, "Gabor Braun")
 
node_bestSolution("cabin1", 168, "Pavel Danihelka")
node_bestSolution("snowman", 66, "Pavel Danihelka")
node_bestSolution("cannons", 39, "Pavel Danihelka")
node_bestSolution("kitchen", 564, "Josef Peterka")
node_bestSolution("cabin2", 383, "David Glass")
node_bestSolution("captain", 483, "David Glass")
node_bestSolution("map", 1541, "Gabor Braun")
 
node_bestSolution("reactor", 163, "Pavel Danihelka")
node_bestSolution("magnet", 408, "Josef Peterka")
node_bestSolution("engine", 256, "Gabor Braun")
node_bestSolution("steel", 185, "Josef Peterka")
node_bestSolution("corridor", 528, "Gabor Braun")
node_bestSolution("experiments", 714, "Gabor Braun")
node_bestSolution("propulsion", 2046, "Gabor Braun")
 
node_bestSolution("aztec", 376, "Mark Byers")
node_bestSolution("gems", 59, "Mark Byers")
node_bestSolution("chest", 279, "Gabor Braun")
node_bestSolution("alibaba", 459, "Gabor Braun")
node_bestSolution("cave", 186, "Josef Peterka")
node_bestSolution("grail", 1725, "Gabor Braun")
 
node_bestSolution("tetris", 134, "Gabor Braun")
node_bestSolution("emulator", 620, "Gabor Braun")
node_bestSolution("warcraft", 573, "Josef Peterka")
node_bestSolution("windoze", 549, "David Glass")
node_bestSolution("hardware", 631, "Masaaki Irie")
node_bestSolution("floppy", 998, "Gabor Braun")
 
node_bestSolution("hanoi", 404, "Masaaki Irie")
node_bestSolution("rush", 852, "Miroslav Olšák")
node_bestSolution("fdto", 251, "Ronny Standtke")
node_bestSolution("rotate", 213, "Masaaki Irie")
node_bestSolution("nowall", 418, "Masaaki Irie")
node_bestSolution("hole", 465, "Brian Raiter")
node_bestSolution("key", 596, "Brian Raiter")
node_bestSolution("keys", 283, "Masaaki Irie")
node_bestSolution("linux", 663, "Masaaki Irie")

node_bestSolution("electromagnet", 482, "Josef Peterka")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/worldfame.lua <==

node_bestSolution("start", 54, "Pavel Danihelka")
node_bestSolution("briefcase", 225, "Pavel Danihelka")
node_bestSolution("cellar", 375, "Pavel Danihelka")
node_bestSolution("library", 111, "Pavel Danihelka")
node_bestSolution("stairs", 163, "Pavel Danihelka")
node_bestSolution("broom", 193, "Ivo Danihelka")
node_bestSolution("reef", 169, "Pavel Danihelka")
node_bestSolution("wc", 100, "Pavel Danihelka")
 
node_bestSolution("submarine", 83, "Pavel Danihelka")
node_bestSolution("party1", 236, "Mark Byers")
node_bestSolution("elk", 257, "Pavel Danihelka")
node_bestSolution("wreck", 91, "Hynek Vychodil")
node_bestSolution("viking1", 119, "Pavel Danihelka")
node_bestSolution("airplane", 235, "Johannes Drescher")
node_bestSolution("bathyscaph", 82, "Pavel Danihelka")
node_bestSolution("tank", 402, "Josef Peterka")
node_bestSolution("viking2", 341, "Uoti Urpala")
node_bestSolution("party2", 283, "Gabor Braun")
node_bestSolution("gods", 533, "Félix Marcotte-Gagnon")
 
node_bestSolution("elevator1", 200, "Pavel Danihelka")
node_bestSolution("city", 481, "Gabor Braun")
node_bestSolution("ufo", 283, "Gabor Braun")
node_bestSolution("columns", 283, "Josef Peterka")
node_bestSolution("pavement", 500, "Erik Hajduk")
node_bestSolution("pyramid", 246, "Johan Rönnblom")
node_bestSolution("music", 393, "Josef Peterka")
node_bestSolution("crabshow", 340, "Gabor Braun")
node_bestSolution("elevator2", 455, "Gabor Braun")
node_bestSolution("atlantis", 531, "Uoti Urpala")
 
node_bestSolution("corals", 254, "Erik Hajduk")
node_bestSolution("labyrinth", 278, "Mark Byers")
node_bestSolution("imprisoned", 275, "Josef Peterka")
node_bestSolution("society", 110, "Radovan Málek")
node_bestSolution("creatures", 447, "Josef Peterka")
node_bestSolution("cancan", 578, "Mark Byers")
node_bestSolution("pearls", 475, "Erik Hajduk")
node_bestSolution("turtle", 654, "Masaaki Irie")
 
node_bestSolution("computer", 156, "Josef Peterka")
node_bestSolution("noground", 44, "Heiko Luettges")
node_bestSolution("bathroom", 90, "Josef Peterka")
node_bestSolution("duckie", 98, "Ronny Standtke")
node_bestSolution("puzzle", 144, "Josef Peterka")
node_bestSolution("dump", 426, "Josef Peterka")
node_bestSolution("barrel", 1364, "Gabor Braun")
 
node_bestSolution("cabin1", 168, "Pavel Danihelka")
node_bestSolution("snowman", 66, "Pavel Danihelka")
node_bestSolution("cannons", 39, "Pavel Danihelka")
node_bestSolution("kitchen", 564, "Josef Peterka")
node_bestSolution("cabin2", 383, "David Glass")
node_bestSolution("captain", 417, "Erik Hajduk")
node_bestSolution("map", 1541, "Gabor Braun")
 
node_bestSolution("reactor", 163, "Pavel Danihelka")
node_bestSolution("magnet", 408, "Josef Peterka")
node_bestSolution("engine", 256, "Gabor Braun")
node_bestSolution("steel", 185, "Josef Peterka")
node_bestSolution("corridor", 528, "Gabor Braun")
node_bestSolution("experiments", 710, "Erik Hajduk")
node_bestSolution("propulsion", 2046, "Gabor Braun")
 
node_bestSolution("aztec", 376, "Mark Byers")
node_bestSolution("gems", 59, "Mark Byers")
node_bestSolution("chest", 279, "Gabor Braun")
node_bestSolution("alibaba", 459, "Gabor Braun")
node_bestSolution("cave", 186, "Josef Peterka")
node_bestSolution("grail", 1725, "Gabor Braun")
 
node_bestSolution("tetris", 134, "Gabor Braun")
node_bestSolution("emulator", 620, "Gabor Braun")
node_bestSolution("warcraft", 573, "Josef Peterka")
node_bestSolution("windoze", 549, "David Glass")
node_bestSolution("hardware", 631, "Masaaki Irie")
node_bestSolution("floppy", 998, "Gabor Braun")
 
node_bestSolution("hanoi", 404, "Masaaki Irie")
node_bestSolution("rush", 852, "Miroslav Olšák")
node_bestSolution("fdto", 243, "Masaaki Irie")
node_bestSolution("rotate", 213, "Masaaki Irie")
node_bestSolution("nowall", 418, "Masaaki Irie")
node_bestSolution("hole", 459, "Masaaki Irie")
node_bestSolution("key", 560, "Masaaki Irie")
node_bestSolution("keys", 281, "Erik Hajduk")
node_bestSolution("linux", 665, "Masaaki Irie")

node_bestSolution("electromagnet", 480, "Erik Hajduk")
